@@ -120,15 +120,17 @@ def restore(ctx: click.Context, all_: bool, path: Tuple[str]) -> None:
 
 
 @main.command()
+@click.argument("path", nargs=-1, type=click.Path())
 @click.pass_context
-def remote_sync(ctx: click.Context) -> None:
+def remote_sync(ctx: click.Context, path: Tuple[str, ...]) -> None:
     """Create project remotes corresponding to remotes in the Metagit repository."""
     with ctx.obj["manager"]:
         repo = metagit.MetagitRepo.for_path(
             ctx.obj["path"],
             search_parent_directories=True,
         )
-        repo.sync_remotes()
+        for p in path or [None]:
+            repo.sync_remotes(p)
 
 
 @main.command()
